Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(136)

Unified Diff: remoting/host/remoting_me2me_host.cc

Issue 1179953006: [Merge to M44] Chromium changes to statically link ffmpeg. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2403
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/remoting_me2me_host.cc
diff --git a/remoting/host/remoting_me2me_host.cc b/remoting/host/remoting_me2me_host.cc
index 3573414d075f307f6b1629097c2886d3f5603ddb..8e5b3f66c8a5131a04ec8fb891cd231fa8fbb73b 100644
--- a/remoting/host/remoting_me2me_host.cc
+++ b/remoting/host/remoting_me2me_host.cc
@@ -1553,8 +1553,8 @@ int HostProcessMain() {
// single-threaded.
net::EnableSSLServerSockets();
- // Ensures runtime specific CPU features are initialized.
- media::InitializeCPUSpecificMediaFeatures();
+ // Ensures that media library and specific CPU features are initialized.
+ media::InitializeMediaLibrary();
// Create the main message loop and start helper threads.
base::MessageLoopForUI message_loop;
« no previous file with comments | « remoting/host/it2me/it2me_native_messaging_host.cc ('k') | testing/chromoting/chromoting_integration_tests.isolate » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698